==> haskell-ghc-tcplugins-extra-0.4.5-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-tcplugins-extra
version:              0.4.5
visibility:           public
id:                   ghc-tcplugins-extra-0.4.5-5mgon709s6d5gkJkzY1oRs
key:                  ghc-tcplugins-extra-0.4.5-5mgon709s6d5gkJkzY1oRs
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             https://github.com/clash-lang/ghc-tcplugins-extra#readme
synopsis:             Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.

category:             Type System
abi:                  f980b3c6a085840e635819d9186fe7ab
exposed:              True
exposed-modules:      GHC.TcPluginM.Extra
hidden-modules:
    Internal GhcApi.Constraint GhcApi.Predicate GhcApi.GhcPlugins
    Internal.Type Internal.Constraint Internal.Evidence

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-tcplugins-extra-0.4.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-tcplugins-extra-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-tcplugins-extra
hs-libraries:         HSghc-tcplugins-extra-0.4.5-5mgon709s6d5gkJkzY1oRs
depends:              base-4.16.4.0 ghc-9.2.8
haddock-interfaces:
    /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock

haddock-html:         /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-tcplugins-extra-0.4.6-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-tcplugins-extra
version:              0.4.6
visibility:           public
id:                   ghc-tcplugins-extra-0.4.6-9uHiztiXkouG86ImZZc9vs
key:                  ghc-tcplugins-extra-0.4.6-9uHiztiXkouG86ImZZc9vs
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             https://github.com/clash-lang/ghc-tcplugins-extra#readme
synopsis:             Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.

category:             Type System
abi:                  eb3c8434752b0f2024ff169419dbd893
exposed:              True
exposed-modules:      GHC.TcPluginM.Extra
hidden-modules:
    Internal GhcApi.Constraint GhcApi.Predicate GhcApi.GhcPlugins
    Internal.Type Internal.Constraint Internal.Evidence

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-tcplugins-extra-0.4.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-tcplugins-extra-0.4.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-tcplugins-extra
hs-libraries:         HSghc-tcplugins-extra-0.4.6-9uHiztiXkouG86ImZZc9vs
depends:              base-4.16.4.0 ghc-9.2.8
haddock-interfaces:
    /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock

haddock-html:         /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
